Struct synstructure::BindingInfo [−][src]
Information about a specific binding. This contains both an Ident
reference to the given field, and the syn &'a Field descriptor for that
field.
This type supports quote::ToTokens, so can be directly used within the
quote! macro. It expands to a reference to the matched field.
Fields
binding: IdentThe name which this BindingInfo will bind to.
style: BindStyleThe type of binding which this BindingInfo will create.
Implementations
impl<'a> BindingInfo<'a>[src]
impl<'a> BindingInfo<'a>[src]pub fn ast(&self) -> &'a Field[src]
Returns a reference to the underlying syn AST node which this
BindingInfo references
pub fn pat(&self) -> TokenStream[src]
Generates the pattern fragment for this field binding.
Example
let di: syn::DeriveInput = syn::parse_quote! { enum A { B{ a: i32, b: i32 }, C(u32), } }; let s = Structure::new(&di); assert_eq!( s.variants()[0].bindings()[0].pat().to_string(), quote! { ref __binding_0 }.to_string() );
pub fn referenced_ty_params(&self) -> Vec<&'a Ident>[src]
Returns a list of the type parameters which are referenced in this field’s type.
Caveat
If the field contains any macros in type position, all parameters will be considered bound. This is because we cannot determine which type parameters are bound by type macros.
Example
let di: syn::DeriveInput = syn::parse_quote! { struct A<T, U> { a: Option<T>, b: U, } }; let mut s = Structure::new(&di); assert_eq!( s.variants()[0].bindings()[0].referenced_ty_params(), &["e::format_ident!("T")] );