Struct synstructure::VariantAst
[−]
[src]
pub struct VariantAst<'a> {
pub ident: &'a Ident,
pub attrs: &'a [Attribute],
pub data: &'a VariantData,
pub discriminant: &'a Option<ConstExpr>,
}This type is similar to syn's Variant type, however each of the fields
are references rather than owned. When this is used as the AST for a real
variant, this struct simply borrows the fields of the syn Variant,
however this type may also be used as the sole variant for astruct.
Fields
ident: &'a Ident
attrs: &'a [Attribute]
data: &'a VariantData
discriminant: &'a Option<ConstExpr>